==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleProvidersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>{
  public ConsoleProvidersFluentImpl() {
  }
  public ConsoleProvidersFluentImpl(io.fabric8.openshift.api.model.operator.v1.ConsoleProviders instance) {
    this.withStatuspage(instance.getStatuspage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder statuspage;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildStatuspage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider getStatuspage() {
    return this.statuspage!=null?this.statuspage.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider buildStatuspage() {
    return this.statuspage!=null?this.statuspage.build():null;
  }
  public A withStatuspage(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider statuspage) {
    _visitables.get("statuspage").remove(this.statuspage);
    if (statuspage!=null){ this.statuspage= new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} return (A) this;
  }
  public java.lang.Boolean hasStatuspage() {
    return this.statuspage != null;
  }
  public A withNewStatuspage(java.lang.String pageID) {
    return (A)withStatuspage(new StatuspageProvider(pageID));
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage() {
    return new io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluentImpl.StatuspageNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
    return new io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluentImpl.StatuspageNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editStatuspage() {
    return withNewStatuspageLike(getStatuspage());
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage() {
    return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
    return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleProvidersFluentImpl that = (ConsoleProvidersFluentImpl) o;
    if (statuspage != null ? !statuspage.equals(that.statuspage) :that.statuspage != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(statuspage,  additionalProperties,  super.hashCode());
  }
  public class StatuspageNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.StatuspageProviderFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatuspageNestedImpl(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(this, item);
    }
    StatuspageNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder builder;
    public N and() {
      return (N) ConsoleProvidersFluentImpl.this.withStatuspage(builder.build());
    }
    public N endStatuspage() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConsoleProvidersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent<A>{
  public ConsoleProvidersFluentImpl() {
  }
  public ConsoleProvidersFluentImpl(io.fabric8.openshift.api.model.operator.v1.ConsoleProviders instance) {
    this.withStatuspage(instance.getStatuspage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder statuspage;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildStatuspage instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider getStatuspage() {
    return this.statuspage!=null?this.statuspage.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.StatuspageProvider buildStatuspage() {
    return this.statuspage!=null?this.statuspage.build():null;
  }
  public A withStatuspage(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider statuspage) {
    _visitables.get("statuspage").remove(this.statuspage);
    if (statuspage!=null){ this.statuspage= new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} return (A) this;
  }
  public java.lang.Boolean hasStatuspage() {
    return this.statuspage != null;
  }
  public A withNewStatuspage(java.lang.String pageID) {
    return (A)withStatuspage(new StatuspageProvider(pageID));
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage() {
    return new io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluentImpl.StatuspageNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
    return new io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluentImpl.StatuspageNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editStatuspage() {
    return withNewStatuspageLike(getStatuspage());
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage() {
    return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
    return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleProvidersFluentImpl that = (ConsoleProvidersFluentImpl) o;
    if (statuspage != null ? !statuspage.equals(that.statuspage) :that.statuspage != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(statuspage,  additionalProperties,  super.hashCode());
  }
  public class StatuspageNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.StatuspageProviderFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StatuspageNestedImpl(io.fabric8.openshift.api.model.operator.v1.StatuspageProvider item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(this, item);
    }
    StatuspageNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.StatuspageProviderBuilder builder;
    public N and() {
      return (N) ConsoleProvidersFluentImpl.this.withStatuspage(builder.build());
    }
    public N endStatuspage() {
      return and();
    }
    
  }
  
}
